@@ -1,14 +1,14 @@
-ci <- function(TE, seTE, level = 0.95, df = NULL) {
+ci <- function(TE, seTE, level = 0.95, df = NULL, null.effect = 0) {
 
   if (level <= 0 | level >= 1)
     stop("no valid level for confidence interval")
 
-  alpha <- 1-level
+  alpha <- 1 - level
   
   if (is.null(df)) {
     lower  <- TE - qnorm(1 - alpha / 2)*seTE
     upper  <- TE + qnorm(1 - alpha / 2)*seTE
-    zscore <- TE / seTE
+    zscore <- (TE - null.effect) / seTE
     pval   <- 2 * pnorm(abs(zscore), lower.tail = FALSE)
     df <- NA
   }
@@ -20,7 +20,7 @@ ci <- function(TE, seTE, level = 0.95, df = NULL) {
     upper <- ifelse(!is.na(df),
                     TE + qt(1 - alpha / 2, df = df)*seTE,
                     TE + qnorm(1 - alpha / 2)*seTE)
-    zscore <- TE / seTE
+    zscore <- (TE - null.effect) / seTE
     pval <- ifelse(!is.na(df),
                    2 * pt(abs(zscore), df = df, lower.tail = FALSE),
                    2 * pnorm(abs(zscore), lower.tail = FALSE))
@@ -30,5 +30,5 @@ ci <- function(TE, seTE, level = 0.95, df = NULL) {
   list(TE = TE, seTE = seTE,
        lower = lower, upper = upper,
        z = zscore, p = pval, level = level,
-       df = df)
+       df = df, null.effect = null.effect)
 }
