@@ -120,6 +120,13 @@ metarate <- function(event, time, studlab,
                data, enclos = sys.frame(sys.parent()))
   chknull(time)
   ##
+  ## Catch incr from data:
+  ##
+  if (!missing(incr))
+    incr <- eval(mf[[match("incr", names(mf))]],
+                 data, enclos = sys.frame(sys.parent()))
+  chknumeric(incr, min = 0)
+  ##
   ## Catch studlab, byvar, subset from data:
   ##
   studlab <- eval(mf[[match("studlab", names(mf))]],
@@ -148,6 +155,9 @@ metarate <- function(event, time, studlab,
   chklength(time, k.All, fun)
   chklength(studlab, k.All, fun)
   ##
+  if (length(incr) > 1)
+    chklength(incr, k.All, fun)
+  ##
   if (!missing.byvar)
     chklength(byvar, k.All, fun)
   ##
@@ -213,6 +223,8 @@ metarate <- function(event, time, studlab,
     data$.time <- time
     data$.studlab <- studlab
     ##
+    data$.incr <- incr
+    ##
     if (!missing.byvar)
       data$.byvar <- byvar
     ##
@@ -236,6 +248,10 @@ metarate <- function(event, time, studlab,
     event <- event[subset]
     time  <- time[subset]
     studlab <- studlab[subset]
+    ##
+    if (length(incr) > 1)
+      incr <- incr[subset]
+    ##
     if (!missing.byvar)
       byvar <- byvar[subset]
   }
@@ -280,7 +296,7 @@ metarate <- function(event, time, studlab,
   sparse <- any(sel, na.rm = TRUE)
   ##
   if (method == "GLMM" & sparse)
-    if ((!missing(incr) & incr != 0) |
+    if ((!missing(incr) & any(incr != 0)) |
         (!missing(allincr) & allincr ) |
         (!missing(addincr) & addincr)
         )
@@ -289,11 +305,11 @@ metarate <- function(event, time, studlab,
   ## No need to add anything to cell counts for arcsine transformation
   ##
   if (addincr)
-    incr.event <- rep(incr, k.all)
+    incr.event <- if (length(incr) == 1) rep(incr, k.all) else incr
   else
     if (sparse)
       if (allincr)
-        incr.event <- rep(incr, k.all)
+        incr.event <- if (length(incr) == 1) rep(incr, k.all) else incr
       else
         incr.event <- incr * sel
     else
@@ -388,7 +404,8 @@ metarate <- function(event, time, studlab,
   ##
   ##
   res <- list(event = event, time = time,
-              incr = incr, sparse = sparse,
+              incr = if (length(unique(incr)) == 1) unique(incr) else incr,
+              sparse = sparse,
               allincr = allincr, addincr = addincr,
               incr.event = incr.event)
   ##
